// This project is a very simple demo for reading data in a CSV file (comma-separated
// values) and parsing the data into individual fields. You can try this out by
// opening the file included in this project. Note: my CSV file has commas at the ends
// each line. If you dump an Excel file as CSV, it will not have commas at the end
// and this demo will miss the final field on a record.


import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import javax.swing.*;

import java.awt.*;
import java.awt.event.*;
public class Control extends JComponent implements ActionListener{
	JButton goBtn = new JButton("Go");
	File inFile = null;
	public Control() {
		add(goBtn);
		setLayout(new FlowLayout());
		goBtn.addActionListener(this);
		readDataFile();
	}
	void readDataFile() {
		// The user chose to work with files so here we are.
		// Create a String holding the new file's path. Adjust this
		// for your own file system.
		String path = "";
		JFileChooser fc = new JFileChooser();
		fc.setCurrentDirectory(null); // sets to default directory to start browsing

		try {
			int returnValue = fc.showOpenDialog(null);
			// If the user clicked ok...
			if (returnValue == JFileChooser.APPROVE_OPTION) {
				inFile = new File(fc.getSelectedFile().getPath());
				// Open and read the file that we just selected.
				readRecords();
				// reset inFile to null (just being tidy)
				inFile = null;
			}
		} catch (NullPointerException e) {
			System.out.println(e);
		}
	}
	void readRecords() {
		// Assuming that this is a comma separated data 
		// file...
		try {
			FileReader reader = new FileReader(inFile);
			// Use a buffered stream--it's easier to read strings this way
			BufferedReader br = new BufferedReader(reader);
			String line;
			// Go through the file line by line until the end
			while ((line = br.readLine()) != null) {
				// we successfully read a line. Print it out and then parse.
				System.out.println(line);
				parseRecord(line);
			}
			reader.close();
		}
		catch (IOException e) {
			System.out.println(e);
		}

	}
	public void parseRecord (String r) {
		// Read the string character by character, looking for comma characters.
		// A comma signifies the end of a field. So, pull out the text from the 
		// starting point until the comma as data.
		int index = 0; // original index in string	
		int start = 0; // starting point for first field
		while (index < r.length()) { // while there are still characters in the string...
			if (r.charAt(index) == ',') {
				// found a comma indicating the end of a field
				// Or, found the last field (with no comma at the end)
				// Copy the data into field
				// Now you can parse field however you want (int, float, leave as string,
				// or whatever else the data is supposed to represent).
				String field = r.substring(start, index);
				System.out.println("found " + field);
				// Update start so it is now one character further than the comma
				// and ready to parse the next field.
				start = index + 1;
			}
			// Update index whether or not we read a comma
			index++;
		}
	}
	@Override
	public void actionPerformed(ActionEvent arg0) {
		// TODO Auto-generated method stub
		readDataFile();
	}
}
